Fossil Free South Africa: position paper

# Why South Africans should demand investments that don’t expose them to the moral and financial hazards of fossil fuels
> Researched and written by David Le Page, FFSA campaign coordinator, February 2017. This position paper has been adapted, with thanks and permission, from a similar paper commissioned by the African Climate Reality Project and Food & Trees for Africa. 
## Further points to include
- investments cannibalising each other through climate change
- the Task Team on Climate Related Disclosure
- the tools to manage decarbonised investments exist (MSCI)
- stranded assets and the carbon bubble
- the current status of the global divestment movement (extract from annual report)
## Summary
- Despite progress in international agreements on carbon emissions, the unexpectedly strong growth of low-carbon technologies, and an apparent stabilisation in annual global carbon emissions, the world is still on track to pump more carbon dioxide (CO₂) into the atmosphere – in total – than is safe. (Because CO₂ lingers in the atmosphere, it is cumulative emissions, not annual emissions, that require urgent, deep restraint.)
- Many estimates of the economic damage likely to be caused by climate change “tell us nothing about the most important driver of the [social cost of carbon], the possibility of a catastrophic climate outcome”.
- Existing agreements on emissions reductions are predicated in good part on the dangerous assumption that after 2050, CO₂ can be sucked back out of the atmosphere using so-called “negative emissions technologies” that do not yet exist.
- Many fossil fuel companies continue to obstruct the transition to renewable energy. 
- Fossil fuels are not just the cause of climate change, but are also strongly linked to air and water pollution, economic and resource instability, dangerous workplaces, corruption, and armed conflict. 
- Fossil fuels are a finite resource. They will run out. Replacements will be needed, sooner or later.
- If global civil society succeeds in winning the battle for proper regulation of carbon emissions, trillions of dollars of investments in fossil fuel companies and infrastructure may turn out to be ‘stranded assets’.
- Annual subsidies to fossil fuels in SA may exceed R60 billion. This amounts to enormous payments for the kind of development that amounts to burning your house down to keep warm.
## Climate change

**The context for climate change**
Our lives are a mostly invisible and glorious symphony played by a multitude of hidden orchestras, from the bacteria that digest our food in our guts to the oceanic phytoplankton that produce most of the oxygen in the air we breathe. Our lives depend on a stable environment and constant flow of key resources, particularly clean water and food, to remain alive. In modern cultures, these resources find their way to us through a multitude of complex social and technological systems that because of their complexity and energy intensity may be more vulnerable to breakdown than they may appear (Motesharrei et al., 2014; Ahmed, 2014).
The high-consumption lifestyle that many are living and many more aspire to, depends on a level of consumption that can no longer be sustained without critically damaging Earth’s ‘life support systems’. It has been calculated by the Global Footprint Network that human civilisation over-stepped the biocapacity of the planet at some point in the 1980s. Since then, we have been living in overshoot:

> Today humanity uses the equivalent of 1.6 planets to provide the resources we use and absorb our waste. This means it now takes the Earth one year and six months to regenerate what we use in a year.

This overshoot shows itself in the destruction of soils, forests, fisheries, the extinction of species, and the depletion of key non-renewable resources such as phosphorus. We are even running out of a resource that most of us would assume is unlimited: sand (Beiser, 2016).
The various dimensions of ecological damage have been described within the framework of a [‘safe operating space for humanity’](http://www.stockholmresilience.org/research/planetary-boundaries/planetary-boundaries/about-the-research/the-nine-planetary-boundaries.html), the boundaries of which must be respected if humanity is to continue flourishing.
If we are to turn away from causing the biophysical decline of ‘Spaceship Earth’, and the social chaos it is already bringing, there are arguably three vital global transformations that are required. These have been summarised by Johan Rockström (2014), one of the leading authors of the ‘planetary boundaries’ framework, as:

- Creating sustainable food systems (that capture carbon in soils)
- A fossil fuel-free world economy
- Transition to a circular economy

We might perhaps add to that: 

- a more widespread culture of human respect for life and living systems.

One of the most critical areas of damage to the environment is permanent damage to a key factor that has allowed the development of human civilisation: a stable climate, now threatened principally by the burning of oil, gas and coal, and land-use change.

**The causes of climate change**
Greenhouse gases are those gases, such as carbon dioxide (CO₂) and water vapour, that trap heat in the atmosphere. There are natural and human sources of greenhouse gases.
The natural balance of greenhouse gases is a good thing: it has kept the temperature of the Earth stable at levels mostly comfortable for human development over the past 10,000 years. Without natural greenhouse gases, Earth’s average surface temperature would be -18°C (Ma 1998). (On Venus, where the atmosphere is mostly CO₂, the surface temperature exceeds 400°C.)
Before the Industrial Revolution, the level of carbon dioxide in the atmosphere was around 280 parts per million. However, over the past 200 years, human activity has driven that level to over 400 parts per million.

**Table 1: Human contributions to global warming**

**Greenhouse gas**
**Sources**
**Proportion**
Carbon dioxide (CO₂)
Burning of fossil fuels: coal, oil and gas
~65%
Carbon dioxide (CO₂)
Deforestation
~12%
Methane (CH₄)
Agriculture (esp. livestock and rice fields), fossil fuel extraction, landfill decay
~14%
Nitrous oxide (N₂O)
Agriculture (especially nitrogen-fertilised soils and livestock waste), industrial processes
~6%
Fluorinated gases (‘F gases’)
Industrial processes
~2%


*Sources: Guardian, 2011; US EPA*

The consequence has been a steady rise in temperature over the past century. Average global temperatures have increased nearly one degree.

**The human ‘fingerprint’ on CO₂ increases**
There are a number of ways in which it can be determined that human activity is responsible for increased warming. These include:

- The isotopic form of additional CO₂ in the atmosphere is consistent with that found in fossil fuels.
- Atmospheric oxygen is declining as carbon is burned.
- If warming was caused by increased solar activity, there would be warming throughout the atmosphere, but in fact the lower levels of the atmosphere are warming as the upper levels cool: the warming pattern expected from increased greenhouse gases.
- Coral records over the past few centuries show a sharp increase in the amount of fossil fuel-typical carbon.
- Less heat is escaping to space at the wavelengths absorbed by CO₂.
- The amount of CO₂ dissolved in the ocean is increasing sharply, causing the seas to become more acid threatening marine food chains.

**The global risks from burning fossil fuels due to climate change**
The risks of climate change include increased levels of extreme weather such as storms, floods, droughts, sea-level rise and heat waves. These shifting weather events can have knock-on effects on existing natural systems, causing deforestation, melting permafrost, wild fires, decreased crop yields, accelerated glacial and snowpack melt, changes in ocean circulatory systems (in turn affecting weather patterns), threats to biodiversity, migration of marine and terrestrial wild life, shifting patterns of disease.
Increased levels of atmospheric carbon dioxide are also causing ocean acidification, threatening marine food chains.
It is important to appreciate that climate change is not just a future risk: it is already creating significant environmental, economic, social and human costs.

https://www.theatlas.com/i/atlas_N1TIXjyrx.png


Estimated annual damage due to climate change runs close to 1% of global GDP (Climate Vulnerability Monitor 2012), and the additional costs of the fossil fuel industry cost close to another 0,7% of global GDP. These combined costs could double by 2030.
**Runaway global warming**
There is a significant risk that the collective effect of human-induced warming will catalyse natural processes that will accelerate the warming process, for example:

- Global warming has already reduced the amount of snow and ice in the Arctic. Because that ice and snow normally reflects a significant amount of heat back into space, the reduction in ice increases the amount of heat being retained.
- Another example is the likely accelerated release natural methane deposits previously permafrost and undersea. Methane is also a greenhouse gas, and when added to the atmosphere, accelerates existing warming.
- Another example is deforestation — as temperatures rise, forests are more likely to burn, in turn adding carbon dioxide to the atmosphere, creating further warming. These “feedbacks” mutually accelerate each other, creating the risk of “runaway” global warming.

**Social risks of climate change**
The political and social impacts of climate change are already unfolding. There is good reason to think that climate change has been a substantial contribution to war and instability in both Darfur and Syria; and to African migration into Western Europe (Baker, 2015).
**The full economic consequences of climate change are either misunderstood or denied**
The leading climate economist Nicholas Nicholas Stern, who convened the British government’s landmark 2006 Stern Review on the Economics of Climate Change, has pointed out (2016) that:

> As the Intergovernmental Panel on Climate Change acknowledged, published [social cost of carbon] estimates ‘lie between a few dollars and several hundreds of dollars’. These values often depend crucially on the ‘discounting’ used to translate future costs to current dollars. The high discount rates that predominate essentially assume that benefits to people in the future are much less important than benefits today. [So] most current models of climate-change impacts make two flawed assumptions: that people will be much wealthier in the future and that lives in the future are less important than lives now.

Mark New (Fossil Free UCT, 2014) of the African Climate Development Initiative at the University of Cape Town explains that while economists’ models of future economic impacts discount the future costs of climate change, in reality the future costs of climate change actually increase, as the external costs of current fossil fuel usage emerge:

> As the impacts of climate change that we are committing to now through not reducing emissions continue to get larger and larger, either the damages or the costs of adaptation continue to get larger. So we have this increasing interest rate that we’re going to be paying further and further into the future.”

Robert Pindyck (2013) of MIT argues that integrated assessment models intended to estimate the social cost of carbon rely on arbitrary inputs, such as chosen discount rates, and “tell us nothing about the most important driver of the SCC [social cost of carbon], the possibility of a catastrophic climate outcome”.

**Systemic threats of climate change**
While economic modeling may anticipate some of the direct risks to economic systems and development, it is more likely that current economic modeling does not fully account for the complex inter-relationships between human society, the economy and the environment that supports them. On this subject, it is worth quoting Stern (2016) at length:

> Current economic models tend to underestimate seriously both the potential impacts of dangerous climate change and the wider benefits of a transition to low-carbon growth... Many estimates of economic losses are based on the outputs of integrated assessment models (IAMs). These models attempt to combine the key elements of biophysical and economic systems... Sadly, most IAMs struggle to incorporate the scale of the scientific risks, such as the thawing of permafrost, release of methane, and other potential tipping points. Furthermore, many of the largest potential impacts are omitted, such as widespread conflict as a result of large-scale human migration to escape the worst-affected areas.

What’s more, climate change is not the only major stress on the human environment; it is just one of the stresses that is closest to critical levels.
**What do current levels of climate change mean for Africa?**
According to New (Fossil Free UCT, 2014) two degrees of global warming by 2100 would mean an average three degrees of warming for Africa, because continents warm more than oceans, and drier regions warm faster than wetter regions. In a four-degree warming scenario, Africa faces warming of six or more degrees. “A two degree policy target or a four degree outcome actually means even more significant impacts on the African continent.” This has to be set against a likely doubling of population by 2050, the only continent facing such a demographic boom.
In agriculture, four degrees of warming would mean that maize could no longer be grown in South Africa, and some areas would no longer be cultivable. The 10-15 year droughts that already afflict African rangeland regions would come every two years. New says that dealing with such changes is beyond the scope of technologies such as genetically modified organisms. New also says (and this was in 2014 before new studies suggesting greater possible sea level rise had emerged) that two degrees of warming would mean half a metre of sea level rise by 2100; four degrees would mean a metre of sea-level rise.
In a four-degree world, according to New:

> The Cape Flats disappears… it either has to be protected or starts eroding away or disappearing.
> … it means ripping up every single tarred road in South Africa and replacing it with something that doesn’t melt.
> … it means rebuilding our built environment to cope.
## Non-climate impacts of the fossil fuel industry

Climate may have become the key danger of using fossil fuels, but it is far from being the only danger of using fossil fuels. There are many others.
**Air pollution**
The World Health Organisation estimates there are at least seven million annual deaths globally due to air pollution  (though this figure includes very large numbers of deaths from indoor wood-burning, which remains a key source of household energy across Africa). A recent OECD report (Roy 2016) estimated that annual premature deaths from outdoor air pollution in South Africa are as high as 10,432. Coal smoke can also cause birth defects. Tragically, “the people that are exposed to the smog are almost always the people that cannot afford to pay the doctors' bills for bronchitis, asthma or, worse, lung cancer”, as South African environment minister Edna Molewa observed in 2013. The cost of premature deaths due to air pollution in South Africa has been calculated by the Global Commission on Economy and Climate as close to 1% of GDP annually. Outdoor air pollution also damages crop yields, halving yields at times in parts of India.
**Water pollution**
It is difficult to quantify the full impacts of acid mining drainage from coal mining in South Africa, but one remarkable example is that coal mining has so polluted the Olifants River that Eskom can no longer use river water in its coal power stations (Colvin, 2011).
**Threats to arable land**
In South Africa, for example, 46% of arable land is in Mpumalanga, and of that, 26% is threatened by coal mining.
**Distortion of climate science by fossil fuel companies**
The fossil fuel industry has, over the past 30 years, mounted a systematic campaign to obscure the science of climate change and mislead the public about the link between human activity and global warming. In 2006, the prestigious British Royal Society publicly requested Exxon Mobil to cease its funding of climate denial (Royal Society, 2006). In 2013, the Guardian reported that between 2002 and 2010, ‘anonymous billionaires had donated $120m to more than 100 anti-climate groups working to discredit climate change science’. In 2015, the attorney general of New York opened an investigation into whether Exxon Mobil had lied to the public about the causes of climate change (Gillis and Krauss, 2015). Much of the history of this systematic campaign of denial has been chronicled by the historian Naomi
**Corruption**
The corruption sponsored by the fossil fuel industry goes far beyond attempts to corrupt science. Examples abound. The OECD (2014) notes that the economic sector most prone to instances of bribery is the extractive industries. In the US, fossil fuel companies have spent hundreds of millions of dollars to subvert democracy and limit regulation of their industry (Cray and Montague, 2014). In Nigeria, Shell has infiltrated most government ministries (Smith, 2010). The South African state oil company, PetroSA, has been at the centre of a series of scandals (amaBhungane, 2013). Most recently, in South Africa, the Public Protector’s 2016 report on ‘State capture’ indicated that undue influence probably played a role when the Tegeta coal mine owned by Oakbay Resources secured extraordinarily favourable terms in a deal to supply Eskom’s Arnot Power Station (Karim, 2016).
**Health and safety**
Jobs in the fossil fuel industry, are, on the whole, riskier than those in other energy sectors (Pollin et al., 2014: 29).
**Economic risk from fossil fuels**
Oil price changes, in the current global food system, can bring sharp increases in food and transport costs, with particularly unpleasant consequences for the poor. In the long-run, dependency on any non-renewable resource is economically risky.
**War**
In 2014, conflicts in no less than seven world regions and countries, including Nigeria and South Sudan in Africa, could be linked to oil (Klare, 2014). Though other pretexts were used to justify the globally destabilising 2003 invasion of Iraq, former US Federal Reserve chairman Alan Greenspan, amongst others, was clear that seizing Iraq’s oil was the real reason for invasion (Beaumont and Walters, 2007).
**Non-climate impacts from fossil fuels: Mpumalanga**
A case study in the cumulative non-climate impacts of fossil fuels can be seen in South Africa’s Mpumalanga province (Benchmarks Foundation, 2014).
There, the impacts of the fossil fuel industry include destruction of roads, protests over mining companies’ broken promises, lack of community trust in mining companies, increased unemployment as capital intensive mining replaces agriculture, devaluation of farm land and increased respiratory problems. The severe disruption of local communities also includes increased migration, increased crime, and increased HIV/AIDS.
**The financial risks of the fossil fuel economy**
In South Africa, coal remains a significant export earner, now even more important than gold. 
Even if South Africa neglects to immediately reduce its domestic coal usage, many other countries are moving fast towards decarbonisation, and South Africa’s export earnings from coal risk sharp decline. South Africa needs to prepare for the potential loss of earnings from coal by planning a ‘just transition’ for the coal and energy sectors, as are countries like Germany.

**Table 2: Relative contributions of gold and coal to SA’s economy**


**1993**
**2013**
**Coal**
R37bn
R51bn
**Gold**
R115bn
R31bn


*Source: StatsSA, 2015*

Some might interpret this table as indicating that coal is essential to South Africa’s economy. However, another lesson that can be drawn from it – specifically, the decline of the gold industry – is the danger of economic dependence on non-renewable resources. The Department of Energy says that South Africa’s coal resource will last ‘at least another 50 years’ (SA Department of Energy, n.d.). That is arguably a very short time horizon, and it’s far from certain that there will be a secure supply of coal even that long (Fisher and Downes, 2015):

> Impending coal shortfalls for the existing power stations are a serious risk to energy security. Dubbed the “coal supply cliff”, a massive shortage (in excess of 60 million tons) in coal supply is anticipated from 2018.

If in 50 years time we will be forced to switch to alternative energy sources anyway, why not make the switch now, especially when the alternatives are already far less expensive?
The apparent value of coal to the economy neglects to factor in costs externalised to the environment and society.
Other economic risks of dependency on fossil fuels include the prospect that countries that refuse to reduce their carbon emissions will see other countries retaliate by imposing tariffs on embedded carbon in exports (Davenport, 2016).

## The risk of stranded assets

Consider what would happen if African countries continue to pour money into new fossil fuel projects, only to have these projects rendered obsolete by new standards on global emissions, and by the relatively inexpensive electricity that can now be provided by renewable energy? This scenario is in fact a global problem for the fossil fuel industry and its investors, described as the problem of stranded assets. Fossil fuel companies are valued on their as yet unexploited underground reserves. But if global emissions targets are taken seriously, then approximately 80% of those reserves must be left in the ground.
According to the research NGO Carbon Tracker, by 2011, the world had already used over a third of its 50-year carbon budget of 886 gigatonnes of carbon dioxide, leaving only 565GtCO₂ of kinda-safe space to continue emissions. (The carbon budget is the amount of carbon dioxide scientists guess can still be added to the atmosphere without pushing climate systems to dangerous levels of warming.) But the proven reserves of private and public companies and governments were equivalent to 2,795 GtCO₂:

> Only 20% of the total reserves can be burned unabated, leaving up to 80% of assets technically unburnable.

This is far from being just a risk to Africa’s development. This “carbon bubble” is a risk to investors, and investment fund beneficiaries such as pension holders, around the world – because their investments may be overvalued by $22 trillion.

## Priorities for decarbonisation – electricity

South Africa is one of the world’s top 10 coal producers. It has an extremely carbon-intensive economy, with 70% of primary energy (far above the global average of 30%), and 85% of electricity, coming from coal in 2014.
Some argue that the continued use of fossil fuels is vital for Africa’s development. But often, these are the same voices that, in other contexts, seek to minimise the threat of climate change. On the other hand, significant African voices echo the call of Ghanaian president, John Mahama (Friedman, 2014), who has said:

> Climate change is real, and Africa stands to suffer the most. We can't take the same paradigm that America did or Europe did or even China did. We need to look at the conditions of the day and develop according to those conditions.

African civil society has argued strongly for steering clear of fossil fuels, as in a 2015 letter (Bassey and Berry) addressed to the organisers of a Chatham House Conference on Extractive Industries in Africa:

> Local communities are most affected by extractive industries in Africa, which routinely disrupt and destroy their livelihoods, health, ecosystems and cultural coherence. To exclude their voices strips this event of all legitimacy... Mere lip service is paid to sustainability and inclusivity, and to international protocols to reduce continued global reliance on fossil fuels and cut carbon emissions.

In 2015, the President of the African Development Bank, Akinwumi A. Adesina, said:

> Africa has potential for 11 terawatts of solar energy, 350 gigawatts of hydropower, 110 gigawatts of wind power, and an additional 15 gigawatts of geothermal potential... Africa should accelerate investments in technology, innovations, policies and regulations to speed up a renewables revolution. Africa cannot power its homes or businesses with potential. Africa must unlock its huge renewable energy potential and combine this with conventional energy to light up and power Africa.

Few policymakers appear to have been able to keep up with the pace of technological and financial change in the electricity sector. Those who still believe in the continued need for fossil fuels are likely doing so either on the basis of outdated assumptions or vested interests. The facts are that renewable energy is already producing savings for African economies, as in South Africa (CSIR, 2015):

> ... renewable energy from South Africa's first wind and solar (photovoltaic) projects created R4 billion more financial benefits to the country than they cost during the first six months of 2015.
> 
> The first benefit, derived from diesel and coal fuel cost savings, is pinned at R3.6 billion. This is because 2.0 TWh (terawatt-hours) of wind and solar energy replaced the electricity that would have otherwise been generated from diesel and coal (1.5 TWh from diesel-fired open-cycled gas turbines and 0.5 TWh from coal power stations).
> 
> The second benefit is the saving of R4.6 billion to the economy derived from 203 hours of so-called 'unserved energy' that were avoided thanks to the contribution of the wind and solar projects.

**Table 3: Coal production and  usage in South Africa in 2013**

**Source/usage**
**MTCE (Megatons carbon equiv.)**
**% of total**
Total saleable production
256.3

Less exports
74.6
29%
Plus imports
2.2
71%



**a) Total domestic use**
183.9
(100%)
Electricity
119.8
65%
Synfuel production
39.4
22%
Other uses
13.72
13%
**b) Total by application**
**172.92**





*Source: Department of Mineral Resources, 2015: 72–74. (It’s unclear why totals a) and b) don’t match exactly.)*



As table 3 shows, 65% of all coal produced in South Africa goes towards electricity generation. Decarbonising our electricity sector is therefore an obvious priority.
**The benefits of decarbonisation**
From the above analysis of the dangers of fossil fuels, we can easily list the benefits of decarbonisation:

- A more stable climate
- Cleaner air and water
- Greater global geopolitical stability
- Greater economic stability
- Reduced threats to arable land
- Increased energy and water security
- Increased biodiversity
- Reduced pressure on public expenses
- Flexible, decentralised energy production

Another key benefit will be more jobs.
**Renewable energy creates more and better jobs**
One of the most profound weaknesses of Africa’s society and economy is the very high level of unemployment, especially in rural areas: long-term unemployment among youth in sub-Saharan Africa reached 48.1% in 2014 according to the International Labour Organisation. One of the great actual and potential advantages of a shift towards renewable energy in the electricity sector is job creation, often in remote and otherwise economically marginal areas.
This pattern is internationally consistent. Robert Pollin, a professor of economics at the University of Massachusetts, observes (2016) that:

> Specifically, spending $1 million on clean energy investments generates about 17 jobs across all sectors of the U.S. economy, while spending the same $1 million on maintaining the existing fossil fuel infrastructure produces only about five jobs.

But renewable energy are not just more numerous. They are also better, safer jobs. (Pollin et al., 2014: 29):

> In short, the clean energy investment agenda creates more jobs, better jobs, and a broader distribution of opportunity across wages and skill levels.

In South Africa, the RE industry has created 35,000 operational jobs in the past five years (Moyo, 2016). Another 10 GW of RE capacity is planned for 2025, which will no doubt see a great many more jobs created, certainly rivaling the 90,000 currently employed in more dangerous, less secure jobs in the coal industry.

## Decarbonising the SA electricity sector would save R90 bn a year by 2040

Over the past few years, South Africa has initiated one of the world’s most successful renewable energy development programmes (Onishi, 2016). The Department of Energy has committed to commissioning 13,225 MW of renewable energy generation by 2025, through the Renewable Energy Independent Power Producer’s Procurement Programme (REIPPPP). The programme, established in 2011, has already completed 4 successful bidding rounds, awarding contracts to 92 projects, mostly wind and solar photovoltaic, with some concentrated solar (CSP).
The tariff for solar photovoltaic energy in South Africa fell from R3.65/kwh in Round 1 of the REIPPP to R0.62/kwh in Round 4 (Moyo, 2016). The cost of wind energy fell from R1.15/kwh in Round 1 to R0.62/kwh in Round 4. These costs are almost half the tariff prices for coal from independent power producers (R1.03/kwh), Eskom coal (R1.05/kwh to R1.16/kwh), and nuclear power, which is estimated at between R1.17kwh to R1.30/kwh.
New-build renewable energy is now significantly cheaper than new-build coal or nuclear power, and no longer requires subsidy.
According to Tobias Bischof-Niemz of the Council for Scientific and Industrial Research (Onishi, 2016), decarbonisation, without turning to nuclear energy, is not only viable but will save money: “South Africa is in a very fortunate situation where we can decarbonize our energy system at negative cost.”
If South Africa aimed for a 70% renewable energy target by 2040, this would cut energy costs dramatically (Cloete, 2016):

> The ‘re-optimised’ mix is almost R90-billion a year cheaper by 2040 than the ‘business-as-usual’ scenario,” says Bischof-Niemz, adding that, even if renewable energy was 50% more expensive than assumed, the ‘re-optimised’ option would still be cheaper than the ‘business-as-usual’ approach.
## Obstacles to decarbonisation

There are many formidable obstacles to removing fossil fuels from the energy system:

- **Cultural:** Despite the evidence presented by the growing success of renewable energy, many people still simply find it difficult to imagine an energy system and society that is no longer dependent on fossil fuels. Petrol-fueled cars, for example, have iconic status within the mythos of global consumer society. Our use of fossil fuels is the cataclysmic culmination of humanity’s ancient love of fire, a love we must now curtail or set aside. 
- **Technological:** Despite rapid progress, and potential alternative technologies such as electric cars and bicycles, ground and air heat pumps, solar heat in industrial processes, and electric and hydrogen-fueled aircraft, not all fossil fuel applications can yet be replaced by no-carbon solutions.
- **Political:** As described above, the political influence of the fossil fuel industry in many countries goes far beyond its legitimate democratic weighting.
- **Institutional:** Many of South Africa’s state-owned enterprises are de facto fossil fuel companies.
- **Financial:** Despite ostensible commitments to decarbonisation, global fossil fuel subsidies still amount to over $1 trillion annually. It has been suggested that by diverting fossil fuel subsidies to development, extreme global poverty could be reduced by three-fourths (Sumner, 2016).

**A key obstacle to decarbonisation: Fossil fuel subsidies in South Africa**
Total fossil fuel subsidies across Africa for 2013 were estimated to be $32 billion, dropping to $26 billion in 2015, according to International Monetary Fund analysts (Cody et al, 2015).
In South Africa, the government-owned Central Energy Fund (CEF) has various subsidiaries, including PetroSA, the Strategic Fuel Fund, iGas, the African Exploration Mining and Finance Corporation (which supplies Eskom with coal), and South African Agency for Promotion of Petroleum Exploration and Exploitation (PASA), all of which invest substantial amounts each year in fossil fuel production.
PetroSA accounts for almost all oil and gas production in South Africa. Transnet, another state-owned company, transports the bulk of fossil fuels in South Africa by rail and pipeline.
There are also a range of tax schemes favouring fossil fuel exploration and exploitation. South Africa also managed to secure substantial loans from the World Bank for the construction of the massive coal-fueled
Medupi and Kusile power stations.

**Table 4: SA’s national subsidies to fossil fuel production 2013–2014**

**Subsidy**
**Subsidy type**
**Estimated annual amount**
Funding for hydraulic fracturing (fracking) research
Direct government funding for research
$8m
Promoting exploration and exploitation of natural oil and gas
Direct government funding
$12m
Tax deductions
Tax breaks on exploration, R&D, accelerated depreciation
Unknown


*Source: Garg and Kitson, 2015*

**Table 5: Fossil fuel-related investment by SA’s state-owned enterprises 2013–2014 ($m)**

**SOE**
**Description**
**Fossil fuel sector**
**Annual average 2013/14**
Petro SA
Total Company Capex
Upstream & midstream oil and gas
409
Transnet
Multiproduct pipeline
Distribution
292

Coal lines expansion
Coal Transportation
40
Eskom
Total Company Capex (net of non-fossil fuel costs)
Electricity Generation
4,629
**Total SOE investment**


5,370 (R57 bn)



*Source: Garg and Kitson, 2015*

**Table 6: South Africa’s public finance for fossil fuel production 2013–2014 ($m)**

**Institution**
**Annual avg. fossil fuel finance**
**Domestic**

Development Bank of Southern Africa
70
**International**

Development Bank of Southern Africa
134
Industrial Development Corporation
86
Export Credit Insurance Corporation
102
Multilateral Development Bank shares
33
**Subtotal international**
**355**
**Total public finance for fossil fuels ($ m)**
425
**Total public finance (Rand m)**
4,536

*Source: Garg and Kitson, 2015*

What’s more, the Export Credit Insurance Corporation of SA also provides insurance to South African exporters. In 2015/16, the ECIC’s operating capital of R5 billion supported a total insurance exposure of R25 billion. Much of this covers unspecified mining and liquid natural gas operations (ECIC Annual Report 2016).
From these figures, we can calculate the annual extent of direct and indirect support for fossil fuels by state and state-owned enterprises in South Africa at more than R60bn annually.

## Conclusion

This paper has explained the damages caused by fossil fuels, and the particular dangers posed to South Africa by the climate change caused by burning fossil fuels. The African electricity sector is likely to be one of the main areas of African energy development over coming decades, given that around 600 million people in Africa still lack access to electricity. Though fossil fuels currently play an enormous role in the global economy, supplying the overwhelming majority of human energy needs, their costs to Africans are particularly high, making the case for side-stepping them in development particularly good.
Though the use of electricity for transport has yet to significantly penetrate Africa, the case for decarbonising the electricity sector is already very sound. Once transport technologies begin to electrify, perhaps beginning as in China with intermediate technology like electric bicycles, the benefits will be multiplied for Africans, who already pay very high costs for fossil-fueled transport.
Given the readiness of renewable energy technology, and the willingness of international agencies to fund these technologies, as well as the sharp growth of indigenous renewable energy companies in Africa, the obstacles to electricity sector decarbonisation now lie chiefly in mindsets.
In South Africa, in particular, there is currently no significant coordination of government policy between the departments of the environment, energy and mineral resources. The latter two departments are run almost as if climate change and the need for a secure environment did not exist. This has to change. South Africa needs a coordinated plan for phasing out fossil fuels and fossil fuel subsidies in an orderly transition that includes retraining fossil fuel industry workers, and will end our contribution to climate change, create greater certainty in the business sector and secure the rights and security of workers in the fossil fuel industry through a ‘just transition’.
At the same time, there is an urgent need for transformation in South African capital markets…

## Sources

Ahmed, N., 2014. Nasa-funded study: industrial civilisation headed for “irreversible collapse”? The Guardian.
amaBhungane, 2013. R1bn scandal rocks PetroSA [WWW Document]. URL http://amabhungane.co.za/article/2013-04-26-r1bn-scandal-rocks-petrosa (accessed 11.30.16).
Baker, A., 2015. How Climate Change is Behind the Surge of Migrants to Europe. Time. http://time.com/4024210/climate-change-migrants/.
Bassey, N., Berry, S., 2015. Letter: African civil society and global allies challenge Chatham House conference on “Extractive Industries in Africa” [WWW Document]. Yes to Life no to Mining. URL http://www.yestolifenotomining.org/african-civil-society-global-allies-challenge-chatham-house-conference-extractive-industries-africa/ (accessed 12.5.16).
Beiser, V., 2016. The World’s Disappearing Sand. The New York Times.
http://www.nytimes.com/2016/06/23/opinion/the-worlds-disappearing-sand.html.
Beaumont, P., Walters, J., 2007. Greenspan admits Iraq was about oil, as deaths put at 1.2m [WWW Document]. The Guardian. URL https://www.theguardian.com/world/2007/sep/16/iraq.iraqtimeline (accessed 11.30.16).
Benchmarks Foundation, 2014. South African Coal Mining: Corporate Grievance Mechanisms, Community Engagement Concerns and Mining Impacts. Policy Gap 9. http://www.bench-marks.org.za/research/policy_gap_9.pdf.
Cloete, K., 2016. CSIR study reveals optimistic renewable-energy scenario [WWW Document]. Engineering News. URL http://www.engineeringnews.co.za/article/csir-study-reveals-optimistic-renewable-energy-scenario-2016-11-03 (accessed 12.2.16).
Coady, D., Parry, I., Sears, L. and Baoping Shang, B. How Large Are Global Energy Subsidies? IMF Working Paper. Fiscal Affairs Department. https://www.imf.org/external/pubs/ft/wp/2015/wp15105.pdf
Colvin, Christine, 2011. Coal and Water Futures in South Africa: The case for conserving headwaters in the Enkangala grasslands. WWF-SA. http://awsassets.wwf.org.za/downloads/wwf_coal_water_report_2011_web.pdf.
Cray, C., Montague, P., 2014. The Kingpins of Carbon and their War on Democracy. http://www.greenpeace.org/usa/wp-content/uploads/legacy/Global/usa/planet3/PDFs/Kingpins-of-Carbon.pdf.
Council for Scientific and Industrial Research, 2015. Media release: First half of 2015 sees financial benefits from renewable energy with huge cost savings. 19 August 2015. Archived at http://www.webcitation.org/6mWhY3SUc.
Davenport, C., 2016. Diplomats Confront New Threat to Paris Climate Pact: Donald Trump. The New York Times.
Fisher, N., Downes, G., 2015. Role of coal in SA’s energy security.
Fossil Free UCT, 2014. Mark New speaks at the Fossil Free UCT launch on 30 July 2014 on climate change impacts in Africa. https://www.youtube.com/watch?v=jj5hQ4DToz4. University of Cape Town.
Friedman, L., 2014. Africa Needs Fossil Fuels to End Energy Apartheid [WWW Document]. Scientific American. URL https://www.scientificamerican.com/article/africa-needs-fossil-fuels-to-end-energy-apartheid/ (accessed 12.5.16).
Gillis, J., Krauss, C., 2015. Exxon Mobil Investigated for Possible Climate Change Lies by New York Attorney General. The New York Times. http://www.nytimes.com/2015/11/06/science/exxon-mobil-under-investigation-in-new-york-over-climate-statements.html.
Goldenberg, S., 2013. Secret funding helped build vast network of climate denial thinktanks. The Guardian. https://www.theguardian.com/environment/2013/feb/14/funding-climate-change-denial-thinktanks-network.
Guardian, 2011. What are the main greenhouse gases? [WWW document]. https://www.theguardian.com/environment/2011/feb/04/man-made-greenhouse-gases
Karim, S., 2016. State capture report explained [WWW Document]. URL http://www.groundup.org.za/article/simple-explanation-state-capture-report/ (accessed 11.30.16).
Ma, Qiancheng, 1998. Greenhouse Gases: Refining the Role of Carbon Dioxide [WWW document]. National Aeronautics and Space Administration Goddard Institute for Space Studies. URL http://www.giss.nasa.gov/research/briefs/ma_01/.
Motesharrei, S., Rivas, J., Kalnay, E., 2014. Human and nature dynamics (HANDY): Modeling inequality and use of resources in the collapse or sustainability of societies. Ecological Economics 101, 90–102. doi:10.1016/j.ecolecon.2014.02.014.
Moyo, A., 2016. Renewable industry blasts Eskom after state capture report [WWW Document]. ITWeb Technology News. URL http://www.itweb.co.za/index.php?option=com_content&view=article&id=157431 (accessed 11.15.16).
OECD, 2014. OECD Foreign Bribery Report: An Analysis of the Crime of Bribery of Foreign Public Officials. OECD Publishing. http://dx.doi.org/10.1787/9789264226616-en.
Pindyck, Robert S, 2013. Climate Change Policy: What Do the Models Tell Us? Journal of Economic Literature. Sep 2013, Vol. 51, No. 3: Pages 860-872. http://pubs.aeaweb.org/doi/pdfplus/10.1257/jel.51.3.860.
Pollin, R., 2016. A Just Transition for U.S. Fossil Fuel Industry Workers [WWW Document]. American Prospect. URL http://prospect.org/article/just-transition-us-fossil-fuel-industry-workers (accessed 12.2.16).
Pollin, R., Garrett-Peltier, H., Heintz, J., Hendricks, B., 2014. Green Growth: A U.S. Program for Controlling Climate Change and Expanding Job Opportunities.
Rockström, J., 2014. Plenary session: Growing society sustainably [WWW Document]. Københavns Universitets Videoportal. URL https://video.ku.dk/plenary-session-growing-society (accessed 11.30.16).
Roy, R., 2016. The cost of air pollution in Africa (OECD Development Centre Working Papers). Organisation for Economic Co-operation and Development, Paris.
Royal Society, 2006. Royal Society and ExxonMobil [WWW Document]. URL https://royalsociety.org/topics-policy/publications/2006/royal-society-exxonmobil/ (accessed 11.29.16).
SA Department of Energy, n.d. Coal resources overview [WWW Document]. URL http://www.webcitation.org/6mRzmRT5J (accessed 12.2.16).
Smith, D., 2010. WikiLeaks cables: Shell’s grip on Nigerian state revealed [WWW Document]. The Guardian. URL https://www.theguardian.com/business/2010/dec/08/wikileaks-cables-shell-nigeria-spying (accessed 11.30.16).
StatsSA, 2015. The importance of coal [WWW Document]. Statistics South Africa. URL http://www.statssa.gov.za/?p=4820 (accessed 11.30.16).
Stern, N., 2016. Economics: Current climate models are grossly misleading. Nature News 530, 407. doi:10.1038/530407a
Sumner, A., 2016. We can reduce extreme global poverty by three-fourths — right now [WWW Document]. Vox. URL http://www.vox.com/2016/9/2/12760110/global-poverty-reduction-redistribution (accessed 12.1.16).
US Environmental Protection Agency, n.d. Global Greenhouse Gas Emissions Data [WWW Document]. URL https://www.epa.gov/ghgemissions/global-greenhouse-gas-emissions-data (accessed 11.29.16).

Karl Mathiesen, ‘Existing coal, oil and gas fields will blow carbon budget – study’ The Guardian, 23 September 2016, goo.gl/gVVHS3 ↩︎

